@@ -20,6 +20,7 @@ c
 #include  "Zcoord.h"
 #include  "Zheavyv.h"
 #include  "Zevhnp.h"
+#include  "Zevhnv.h"
 c
         external cblkHeavy
 c
@@ -63,8 +64,13 @@ c      noOfNuc:  all nucleons
 c      noOfInteNuc: interacting nucleons.
 c
 c                                          
-        if(IntModel .eq. 'int2' .and.
-     *      ( pj.code .eq. ktriton .or. pj.code .eq. kdeut) ) then
+c        if(IntModel .eq. 'int2' .and.
+c     *      ( pj.code .eq. ktriton .or. pj.code .eq. kdeut) ) then
+        if( ActiveMdl .eq. 'dpmjet3' ) then
+           call cdpmjet(pj, ia, iz, a, ntp)
+        elseif(ActiveMdl .eq. 'gheisha' .and.
+     *        pj.code .eq. kgnuc  .and. (pj.subcode .eq. 2 .or.
+     *        pj.subcode .eq. 3) ) then
 c                  Gheisha should be called directly
            call chAGheisha(pj, ia, iz, a, ntp)
            noOfFragments = 0
@@ -483,7 +489,12 @@ c                 normalzie
 #include "Zcode.h"
 #include "Zheavyp.h"
       integer code, hg
-      hg = Code2heavyG(code)
+      if(code .ge. kalfa .and. code .le. kiron) then
+         hg = Code2heavyG(code)
+      else
+         call cerrorMsg(
+     *   'ccode2hvgrp should not be used for code # He ~Fe',0)
+      endif
       end
       subroutine ccode2mass(code, mass)
       implicit none
@@ -492,8 +503,13 @@ c                 normalzie
 #include "Zmass.h"
       integer code, hg
       real*8 mass
-      hg = Code2heavyG(code)
-      mass = HeavyG2massN(hg) * (masp+masn)/2
+      if(code .ge. kalfa .and. code .le. kiron) then
+         hg = Code2heavyG(code)
+         mass = HeavyG2massN(hg) * (masp+masn)/2
+      else
+         call cerrorMsg(
+     *   'ccode2mass should not be used for code # He ~Fe',0)
+      endif
       end
 
       
