@@ -1,34 +1,45 @@
 cc       test cmoliere
+c
 c        implicit none
 c        real*8 rho, zave, ave, z2ave, x0, mass
-c        real*8 leng, teta, g1, g2, rl, e1, e2
+c        real*8 leng, teta, g1, g2, rl, e1, e2, ec
 c        integer i, z, cond, imax
-c  
+cc          ~ air  
 c        x0 =364.0
-c        rho = .33
+c        rho = 1.2
 c        zave = 7.36
 c        ave =14.75
 c        z2ave = 53.5
-c        mass = 106.d-3
-c        read(*, *) imax, rl
+c        ec = 80.d-3
+cc         ~  pb
+c        rho = 11.d3
+c        x0 = .56d-2*rho
+c        zave= 82
+c        z2ave= 6724
+c        ave = 204
+c        ec = 7.d-3
+c        read(*, *) imax, rl, x0, rho, zave, ave, z2ave, ec
+
 c        z = 1
+c        mass = 106.d-3
+c
 c        leng = rl*x0/rho
 c  
-c        e1 = 50.
-c        e2 = e1 - rl * 80.d-3
+c        e1 = 5.
+c        e2 = e1 - rl * ec
 c        g1 = e1/mass
 c        g2 = e2/mass
 c        do i =1 , imax
 c           call cmoliere(rho, zave, z2ave, ave, 
-c     * z, mass, g1, g2,  leng, teta, cond)
+c     *     z, mass, g1, g2,  leng, teta, cond)
 c          if(cond .ne. 0) then
 c              write(0, *) 0.
 c           else
-c              write(*, *) sngl(teta**2)
+c             write(*, *) sngl(teta**2)
 c           endif
 c        enddo
-c        end
-c
+c       end
+
       subroutine cmoliere(rhoin, zin, z2in, ain,
      *           z, mass, g1, g2,  leng, teta, cond)
       implicit none
@@ -96,8 +107,7 @@ c         Moliere theory cannot be appliled; use Gaussian later (almost no scatt
       else
          cond = 0
          call cblogb(bp, b, icon)
-         a0 = max(1.d0 - 5/b, 0.d0)  ! actually a0=0 dose not happen becasuse
-c                                      the condtition above.
+         a0 = max(1.d0 - 5/b, 0.d0)  ! use single scattering term if b<=5. 
          icon = 1               ! make 0 if no rejection
 c                the sampling function decomposition is explained in Test/....tex
          do while (icon .ne. 0)
@@ -110,7 +120,7 @@ c             sample reduced angle from exp(-x) dx where x = reduced
 c               angle^2.
                call rndc(u)
                ra2 = -log(u)
-               icon = 0
+               icon =0
             elseif( (a0+a1)/sum .gt. u) then
 c            sample reduced angle from exp(-x) dx (same as above but
 c                  in the region of ra < 1.8
@@ -237,3 +247,6 @@ c
      *        * massratio2
       endif
       end
+
+
+
