@@ -4,7 +4,7 @@ c             hadron A collision by Lund
 
 #include  "Zptcl.h"
 #include  "Zcode.h"
-
+#include  "Zevhnv.h"
 c
         record /ptcl/ pj, a(*)
         integer ia,iz, np
@@ -19,7 +19,10 @@ c
 
          elab=pj.fm.p(4)
          ek = elab - pj.mass
-         if(elab .gt. 5. ) then
+c         if(elab .gt. 5. ) then
+         if(ActiveMdl .eq. 'fritiof1.6'
+     *    .or. ( ActiveMdl .eq. 'byenergy' .and.
+     *           ek .gt. 4.0 ) ) then
 c                lund monte carlo ; fritiof
             call cfritiof(pj, ia, iz,  a, np)
 c              in  above, momentum  is measured from pj.fm so 
@@ -28,10 +31,14 @@ c       ////////
 ccc            call ccheckMom('after fritio: before rot', a, np)
 c      /////////            
             call crot3mom(pj, a, np)
-         elseif(ek  .gt. eintmn  ) then
+         elseif(ek  .gt. eintmn .and.
+     *         ( ActiveMdl .eq. 'nucrin' .or.
+     *          ActiveMdl .eq. 'byenergy' ) ) then
             call cnucrin(pj, ia, iz,  a, np)
             call crot3mom(pj, a, np)
-         elseif(pj.code .eq. knuc .and. pj.subcode .eq. antip) then
+         elseif(pj.code .eq. knuc .and. pj.subcode .eq. antip
+     *      .and. (ActiveMdl .eq. 'nucrin'  .or.
+     *             ActiveMdl .eq. 'byenergy' ) ) then
 c              for anti-barion, no threshold.
             call cnucrin(pj, ia, iz,  a, np)
             call crot3mom(pj, a, np)
