@@ -21,8 +21,8 @@ c	(->   ----------------------------------------------
                               !
                               !  at around shower maximum.   Hybrid AS is always essentially 1-D.
 
-	logical Knockon       !2  Obsolete. If T, Knockon process is considered. Giving F is possible by
-                              !   giving large RecoilKineMinE.
+	logical Knockon       !2  Obsolete. Don't use this. See RecoilKineMinE
+                              !    and KnockonRatio.
 	real*8  AnihiE        !2  if E(positron)  < Eanihi, annihilation is  considered. 
 	real*8  Es            !2  Modified scattering constant. 19.3d-3 GeV
 	real*8  MaxComptonE   !2 Above this energy, Compton is neglected. 
