@@ -137,9 +137,10 @@ c           see if <=mass
               endif
               MovedTrack.p.fm.p(4) = MovedTrack.p.mass
 
-              call cthick2len(TrackBefMove.pos.height, 
-     *          TrackBefMove.vec.coszenith, thick, leng, thick, jcut)
-
+c              call cthick2len(TrackBefMove.pos.height, 
+c     *          TrackBefMove.vec.coszenith, thick, leng, thick, jcut)
+c                   Mar.18
+              call cthick2len(TrackBefMove, thick, leng, thick, jcut)
 c               reset position information in MovedTrack
               call cmoveStreight(leng, TrackBefMove.vec.w)
               MoveStat = Truncated
@@ -180,7 +181,7 @@ c
 
        if(Reverse .eq. 0) then
           nodef = OneDim .ne. 0  .or.
-     *    (mod(HowGeomag, 10) .eq. 1 .and. Zfirst .eq. 0.)
+     *    (mod(HowGeomag, 10) .eq. 1 .and. Zfirst.pos.depth .eq. 0.)
        else
           nodef = .false.
        endif
@@ -209,6 +210,7 @@ c                compute excess path length to be added to streight path
        endif
        end
 c      *************************
+#include "ZsubstRec.h"
        subroutine cmagDef
        implicit none
 #include  "Zobs.h"
@@ -222,55 +224,187 @@ c
 
 c              by  Geomag  (dr and ddirec)
        record /coord/ dispmr, dispmd
+       record /magfield/ tempmag
        real*8  leng
+       real*8 temp1, temp2
 ccc    *   ,norm
        integer i
 
-c^^^^^^^^^   for trial to use B at middle of the path
-c       integer icon
-c       record /coord/  middle
-c^^^^^^^^^
+       integer icon
+       record /coord/  middle
+       logical usemiddle, high, usecmiddle
+       real*8 cheight
+       data cheight/30.d3/  
+       save cheight
 
        leng = IntInfArray(ProcessNo).length
+c
+c            UseRungeKutta         Height       
+c                0                  any         Mag and cmagneticDef
 
-c^^^^^^^^^
-c       middle.x=TrackBefMove.pos.xyz.x + 
-c     *          leng/2 * TrackBefMove.vec.w.x
-c       middle.y=TrackBefMove.pos.xyz.y +
-c     *          leng/2 * TrackBefMove.vec.w.y
-c       middle.z=TrackBefMove.pos.xyz.z + 
-c     *          leng/2 * TrackBefMove.vec.w.z
-c       middle.sys='xyz'
+c                1                 >cheight     middle Mag and cmagneticDef
+c                1                 <            Mag and cmagneticDef
 
-c       call cgeomag(YearOfGeomag,  middle,
-c     *                Mag, icon)
-c       call ctransMagTo('xyz', middle,
-c     *        Mag, Mag)
-c^^^^^^^^^^^
+c                2                 >            middle Mag and cmagneticDef 
+c                                               or cbDefByRK2        
+c                2                 <            Mag and cmagneticDef 
 
-       call cmagneticDef(TrackBefMove, Mag, leng,
+c                3                 >            middle Mag and cmagneticDef 
+c                                               or cbDefByRK        
+c                3                 <            Mag and cmagneticDef 
+
+c                4                 >            use Mag at curved middle point
+c                                               and estimate end point by 
+c                                               cmagneticDef or cbDefByRK2
+c                4                 <            Mag and cmagneticDef   
+
+c                5                 >            use Mag at curved middle point
+c                                               and estimate end point by 
+c                                               cmagneticDef or cbDefByRK
+c                5                 <            Mag and cmagneticDef   
+
+c                6                 >            cbDefByRK2
+c                6                 <            Mag and cmagneticDef 
+
+c                7                 >            cbDefByRK
+c                7                 <            Mag and cmagneticDef 
+c
+c                8      at any height           cbDefUser ; interface is
+c                                               same as cbDefByRK
+c
+       if(UseRungeKutta .eq. 8 ) then
+          call cbDefUser(TrackBefMove,  leng,  dispmr, dispmd)
+          MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
+          goto 100
+       endif
+       high = TrackBefMove.pos.height .gt. cheight
+       usemiddle = ( UseRungeKutta .ge. 1 .and.
+     *               UseRungeKutta .le. 3 .and.
+     *               high )
+       usecmiddle = ( UseRungeKutta .ge. 4 .and.
+     *               UseRungeKutta .le. 5 .and.
+     *               high )
+
+
+       if(usemiddle) then
+          do i = 1, 3
+             middle.r(i) = TrackBefMove.pos.xyz.r(i)+ 
+     *          leng/2 * TrackBefMove.vec.w.r(i)
+          enddo
+          middle.sys='xyz'
+
+          call cgeomag(YearOfGeomag,  middle,
+     *                tempmag, icon)
+          call ctransMagTo('xyz', middle,
+     *        tempmag, tempmag)
+       elseif(usecmiddle) then
+c            get curved middle point
+          call cmagneticDef(TrackBefMove, Mag, leng/2.0d0,
+     *     dispmr, dispmd)
+          do i = 1, 3
+             middle.r(i) = TrackBefMove.pos.xyz.r(i) + dispmr.r(i)
+          enddo
+          middle.sys ='xyz'
+          call cgeomag(YearOfGeomag,  middle,
+     *                tempmag, icon)
+          call ctransMagTo('xyz', middle,
+     *        tempmag, tempmag)
+       endif
+
+       if(usemiddle .and. UseRungeKutta .eq. 1) then
+          Mag = tempmag
+       elseif( usemiddle .and.  UseRungeKutta .eq. 2 ) then
+          temp1 = tempmag.x**2 + tempmag.y**2 + tempmag.z**2
+          temp2 = Mag.x**2 + Mag.y**2 + Mag.z**2
+c           if  dB/B~ dB^2/B^2/2 > 0.4 %, use RungeKutta.
+          if( abs(temp1-temp2)/temp1/2.0 .gt. 4.0d-3) then
+             call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd)
+             MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
+             goto 100
+          else
+             Mag = tempmag
+          endif
+       elseif(usemiddle .and. UseRungeKutta .eq. 3) then
+          temp1 = tempmag.x**2 + tempmag.y**2 + tempmag.z**2
+          temp2 = Mag.x**2 + Mag.y**2 + Mag.z**2
+c           if  dB/B~ dB^2/B^2/2 > 0.45 %, use RungeKutta.
+c                  next 4.5d-3 is very sensitive to cpu time
+c                 if it was 4.0d-3, cpu time becomes twice.
+          if( abs(temp1-temp2)/temp1/2.0 .gt. 4.5d-3) then
+             call cbDefByRK(TrackBefMove,  leng, dispmr, dispmd)
+             MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
+             goto 100
+          else
+             Mag = tempmag
+          endif
+       elseif(usecmiddle .and. UseRungeKutta .eq. 4) then
+          temp1 = tempmag.x**2 + tempmag.y**2 + tempmag.z**2
+          temp2 = Mag.x**2 + Mag.y**2 + Mag.z**2
+c           if  dB/B~ dB^2/B^2/2 > 0.1 %, use RungeKutta.
+          if( abs(temp1-temp2)/temp1/2.0 .gt. 4.0d-3) then
+             call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd)
+             MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
+             goto 100
+          else
+             Mag = tempmag
+          endif
+       elseif(usecmiddle .and. UseRungeKutta .eq. 5) then
+          temp1 = tempmag.x**2 + tempmag.y**2 + tempmag.z**2
+          temp2 = Mag.x**2 + Mag.y**2 + Mag.z**2
+c           if  dB/B~ dB^2/B^2/2 > 0.45 %, use RungeKutta.
+          if( abs(temp1-temp2)/temp1/2.0 .gt. 4.5d-3) then
+             call cbDefByRK(TrackBefMove,  leng, dispmr, dispmd)
+#if defined SUBSTREC             
+             MovedTrack.pos.xyz = dispmr ! this is not a dispalcement vector
+#else 
+             call csubstcoord(dispmr, MovedTrack.pos.xyz)
+#endif
+             goto 100
+          else
+             Mag = tempmag
+          endif
+       endif
+
+       if(UseRungeKutta .le. 5 .or. .not. high ) then
+          call cmagneticDef(TrackBefMove, Mag, leng,
      *     dispmr, dispmd)
 
-       do i = 1,  3
-c               displacement
-c            for obso routine
-c          MovedTrack.pos.xyz.r(i) = MovedTrack.pos.xyz.r(i) +
-c     *         dispmr.r(i)
-          MovedTrack.pos.xyz.r(i) = TrackBefMove.pos.xyz.r(i) +
+          do i = 1,  3
+             MovedTrack.pos.xyz.r(i) = TrackBefMove.pos.xyz.r(i) +
      *         dispmr.r(i)
-c               direction; for obso
-cccc          MovedTrack.vec.w.r(i) = MovedTrack.vec.w.r(i) +
-cccc     *         dispmd.r(i)
-          MovedTrack.vec.w = dispmd
-       enddo
-cc           normalize
-cc       norm = sqrt(MovedTrack.vec.w.r(1)**2 +
-cc     *            MovedTrack.vec.w.r(2)**2 +
-cc     *            MovedTrack.vec.w.r(3)**2)
-cc       do i = 1, 3
-cc           MovedTrack.vec.w.r(i) = MovedTrack.vec.w.r(i)/norm
-cc       enddo
+          enddo
+       elseif(UseRungeKutta .eq. 6) then
+          call cbDefByRK2(TrackBefMove,  leng, dispmr, dispmd)
+#if defined SUBSTREC
+          MovedTrack.pos.xyz = dispmr  ! this is not a dispalcement vector
+#else 
+          call csubstcoord(dispmr, MovedTrack.pos.xyz)
+#endif
+                                      !  but the vector itself.
+       else
+          call cbDefByRK(TrackBefMove,  leng, dispmr, dispmd)
+#if defined SUBSTREC
+          MovedTrack.pos.xyz = dispmr  ! this is not a dispalcement vector
+                                      !  but the vector itself.
+#else 
+          call csubstcoord(dispmr, MovedTrack.pos.xyz)
+#endif
+       endif
+ 100   continue
+#if defined SUBSTREC
+       MovedTrack.vec.w = dispmd
+#else
+       call csubstcoord(dispmd, MovedTrack.vec.w)
+#endif
        end
+c        for IBM AIX
+      subroutine csubstcoord(c1, c2)
+      implicit none
+#include "Zcoord.h"
+      record /coord/ c1, c2   
+      c2 = c1
+      end
+
 c      ==============================================================
        subroutine celecDef(dispx, dispy)
        implicit none
