@@ -10,7 +10,9 @@ c
       integer  needrtn  !  input. 0  --> stop 9999,else control is returned
       integer klena
 
-      write(ErrorOut, '(a)') msg(1:klena(msg))
+      if(klena(msg) .ge. 1) then
+         write(ErrorOut, '(a)') msg(1:klena(msg))
+      endif
       if(needrtn .eq. 0) stop 9999
       end
 
