@@ -20,9 +20,11 @@ c
 
       integer icon
 c
+
       icon = 1
 
 
+
       do while (icon .ne. 0)
 c          sample energy, mass, code (mometum is not given)
          call csampPrimary(incident.p, fin)
@@ -180,7 +182,7 @@ c         inc2.p = incidentp : for IBM, we must  write as follows.
       inc2.p.fm.p(4) = incidentp.fm.p(4)
       inc2.p.mass = incidentp.mass
       call cmkInc(inc2, angle)
-      call ciniTracking
+      call ciniTracking( inc2 )
       call cinitStack
       call cpush(inc2)
       end
@@ -202,7 +204,7 @@ c
 c                                       about primary
       
       call cmkInc2(incident)
-      call ciniTracking
+      call ciniTracking( incident ) 
       call cinitStack
       call cpush(incident)
       end
@@ -458,6 +460,7 @@ c              icon !=0 ==> light cannot come with this angle
             ObsSites(i).minitime = 1.d10
          endif
       enddo
+
       from.t = 0.    ! reset time of incident track.
       end
 c     *************************** inquire incident particle
