@@ -21,9 +21,11 @@ c      ***  do until no more ptcl in stack
       do while (.true.)
 c           get one particle from stack
          call cpop(TrackBefMove, moreptcl)
+
          if(moreptcl .eq. 0) goto 100   !  exit
          call rndsw(jold, 1)            !  specify 1st generator.
          call cifDead(TrackBefMove, icon)  ! generator may be switched to 2
+
 c            AS generation. 
 
          if(ObserveAS .and. icon .ne. 2) then
@@ -75,12 +77,19 @@ c -------------------------------------tracking a ptcl
 #include  "Zobsv.h"
 #include  "Zincidentv.h"
 #include  "Zcode.h"
-c    
+#include  "Zmanagerp.h"
 c                next is for DEBUG
+c//////
+c      logical deb
+c      common /cccdeb/ deb
+c/////////
+ccc   c#define DEBUG 1
+
+
 
       real*8 cosangle
       character*70 msg
-      integer nextwhere
+      integer nextwhere, never
 cc      integer icon
 
 #if DEBUG == 1
@@ -150,6 +159,15 @@ c           it should be decayed.
       endif 
 
       if(MoveStat .eq. Truncated) then
+c        &&&&&&&&&&&&&& some may lose energy by dE/dx etc. 
+c                       This should be recorded
+         if(Job .eq. 'newskel' .and. 
+     *        (MovedTrack.p.fm.p(4) - MovedTrack.p.mass) .lt. 
+     *        KEminObs)  then
+            never = -1
+            call chookEInt(never)
+         endif
+c        &&&&&&&&&&&&
 c              stack current ptcl
          call cpush(MovedTrack)
       elseif(MoveStat .eq. ToInteract ) then
@@ -157,13 +175,7 @@ c              stack current ptcl
 c             reset minimum time to reach the obs level (time from this
 c             hight to the obs. level), if no mag. exists until
 c                  the first collision point. or ptcl goes streight
-            if(mod(HowGeomag, 2) .eq. 1 .or. 
-     *           IncidentCopy.p.charge .eq. 0 .and.
-     *           ObsPlane .ne. 3) then
-               call csetMinTime(MovedTrack)
-            else
-               MovedTrack.t = 0.
-            endif
+            call cresetTimer(MovedTrack)
             Zfirst = MovedTrack
          endif
 #if DETAILED_TRACKING >= 1 
@@ -174,12 +186,41 @@ c                  the first collision point. or ptcl goes streight
          call checkstat('before cinteraction')
 #endif
          call cinteraction
-      elseif(MoveStat .eq. ToBeObserved) then
+c/////////////
+c         if(deb) then
+c            write(*,*) 'after cinte'
+c         endif
+c////////////
+      elseif(MoveStat .eq. ToBeObserved ) then
          if(MovedTrack.p.fm.p(4)-MovedTrack.p.mass 
-     *        .gt. KEminObs) then
+     *        .ge. KEminObs) then    ! .gt. for <= uv6.00
 c             call only for high energy particles
-c                  (at AS generation, some ptcl may have < KEminObs)
+c                  (at AS generation, some ptcl may have < KEminObs
+c                  or some may loose energy by dE/dx etc.
+
             call cobservation(2)
+
+            if(Job .eq. 'newskel' .and.
+     *          EndLevel .lt. NoOfSites .and. 
+     *          MovedTrack.where .eq. EndLevel ) then
+c                in this case, even E> KEminObs must be recorded
+c                 for skeleton making for kahanshin
+c                  where should be +1 at flesh time
+               MovedTrack.where = MovedTrack.where + 1
+               never = -3
+               call chookEInt(never)
+               MovedTrack.where = MovedTrack.where - 1 ! for safty
+            endif
+         elseif(Job .eq. 'newskel'  .and. 
+     *          EndLevel .eq. NoOfSites .and.
+     *          MovedTrack.where .lt. EndLevel )  then
+c            &&&&&&  this is to be recorded
+c                where should be + 1 at flesh time
+            MovedTrack.where = MovedTrack.where + 1
+            never = -2
+            call chookEInt(never)
+            MovedTrack.where = MovedTrack.where - 1
+c            &&&&& 
          endif
 c               update observation place
          if(abs(ObsPlane) .eq. perpendicular) then
@@ -230,6 +271,30 @@ c           made before this
          call cerrorMsg(msg, 0)
       endif   
       end
+      subroutine cresetTimer(aTrack)
+      implicit none
+#include  "Ztrack.h"
+#include  "Ztrackv.h"
+#include  "Ztrackp.h"
+#include  "Zobs.h"
+#include  "Zobsp.h"
+#include  "Zobsv.h"
+#include  "Zincidentv.h"
+#include  "Zcode.h"
+#include  "Zmanagerp.h"
+      record /track/ aTrack
+c             reset minimum time to reach the obs level (time from this
+c             hight to the obs. level), if no mag. exists until
+c                  the first collision point. or ptcl goes streight
+      if(mod(HowGeomag, 2) .eq. 1 .or. 
+     *     IncidentCopy.p.charge .eq. 0 .and.
+     *     ObsPlane .ne. 3) then
+         call csetMinTime(aTrack)
+      else
+c         MovedTrack.t = 0.     ! bug bef uv6.09
+      endif
+      end
+
 #if DEBUG > 0
       subroutine checkstat(str)
       implicit none
@@ -238,15 +303,27 @@ c           made before this
 #include  "Ztrackp.h"
 #include  "Zobs.h"
 #include  "Zobsv.h"
+
+      logical deb
+      common /cccdeb/deb
+
       character*(*) str
       integer i
       integer nc
       data nc/0/
       nc = nc + 1
-      if(nc .gt. 750) then
+c      if(nc .gt. 750) then
+      if( MovedTrack.p.code .eq. 4 .and. 
+     *      MovedTrack.p.charge .eq. 1 .and.
+     *      abs(MovedTrack.p.fm.p(4)-127.939) .le. 1.d-2) then
+         deb =.true.
 
 c         if(TrackBefMove.p.code .eq. 6
-c     *     .and. TrackBefMove.p.charge .eq. -1) then
+c     *     .and. 
+c     *   abs(TrackBefMove.p.fm.p(4)- 14077.514663).lt. 1.d-6) then
+c
+c            deb = .true.
+
             write(*,*) str, ' code=',TrackBefMove.p.code,
      *         ' cg',TrackBefMove.p.charge,
      *         ' e=', TrackBefMove.p.fm.p(4), ' stat=',MoveStat
@@ -435,9 +512,10 @@ c     *         IntInfArray(i).thickness, leng, t, jcut)
             minlen = leng
          endif
       enddo
-      if(leng .ge. minlen) then
+c      if(leng .ge. minlen) then  !   bug in 6.00
+      if(leng .ge. Infty) then  
          ProcessNo = 1
-         IntInfArray(i).length = 1.e5
+         IntInfArray(1).length = 1.e5
       endif         
       if(IntInfArray(ProcessNo).decay .or. jcut .ne. 0) then
 c         In the case  of muon, if individual knockon process  
@@ -449,7 +527,7 @@ c
          if( TrackBefMove.vec.coszenith .lt. 0.) then
             pcut = 300.d3
          else
-            pcut = 10.d3
+            pcut = 30.d3
          endif
          if(IntInfArray(ProcessNo).length .gt. pcut) then
             MoveStat = Truncated
@@ -474,6 +552,7 @@ c        an observation depth.
 c
       call cmaxMovLen(leng, thick)
 
+
       if(leng .lt. IntInfArray(ProcessNo).length ) then
          MoveStat = Truncated
          IntInfArray(ProcessNo).length = leng
